@@ -63,6 +63,9 @@ impl TextTesselationEngine for () {
                 text: text.text.to_owned(),
                 font: text.font.name.to_owned(),
                 size: text.font.size,
+                horizontal_align: text.horizontal_align,
+                vertical_align: text.vertical_align,
+                direction: text.direction,
                 color: raui_to_color(text.color),
                 box_size: (layout.local_space.width(), layout.local_space.height()),
                 matrix,
