@@ -1,5 +1,11 @@
 use crate::Index;
-use raui_core::{widget::WidgetId, Scalar};
+use raui_core::{
+    widget::{
+        unit::text::{TextBoxDirection, TextBoxHorizontalAlign, TextBoxVerticalAlign},
+        WidgetId,
+    },
+    Scalar,
+};
 use serde::{Deserialize, Serialize};
 use std::ops::Range;
 use vek::Vec2;
@@ -35,6 +41,9 @@ pub struct BatchExternalText {
     pub size: Scalar,
     pub color: Color,
     pub box_size: (Scalar, Scalar),
+    pub horizontal_align: TextBoxHorizontalAlign,
+    pub vertical_align: TextBoxVerticalAlign,
+    pub direction: TextBoxDirection,
     pub matrix: [Scalar; 16],
 }
 
